@@ -7,15 +7,15 @@
 # Description : This module is used to control the AMF products
 # Author : Paul Giroux AMF (paul.giroux@amf.ch)
 # Date Created : august 21, 2023
-# Date Modified : november 13, 2023
-# Version : 0.1.1
+# Date Modified : november 15, 2023
+# Version : 0.1.3
 # Python Version : 3.11.4
 # Dependencies : pyserial, ftd2xx
 # License : all Right reserved : Proprietary license (Advanced Microfluidics S.A.)
 # Contact : info [at] amf.ch
 #*******************************************************************************
 
-__version__ = "0.1.1"
+__version__ = "0.1.3"
 __author__ = 'Paul Giroux AMF'
 __credits__ = 'Advanced Microfluidics S.A.'
 
@@ -289,7 +289,7 @@ class AMF:
             return
         return self.receive(integer=integer)
         
-    def receive(self, integer=False, full=False, isfloat = False) -> str:
+    def receive(self, integer=False, full=False, float = False) -> str:
         """
         INPUTS:
             integer: bool # If True, the response will be converted to an integer
@@ -1301,8 +1301,14 @@ class AMF:
             to_dispense = int(volume * 24000 / self.syringeSize)
         return self.pumpRelativeDispense(to_dispense, block = block)
     
-class utile:
+class util:
     def getProductList(specified_type = None) -> list:
+        """
+        INPUTS:
+            specified_type: str # Type of product to find. "SPM" or "RVMFS" or "RVMLP"
+        OUTPUTS:
+            list # List of product found (list of Device type object)
+        """
         result = []
         if os.name == 'nt':
             devicelist = ftd2xx.listDevices()
@@ -1338,7 +1344,7 @@ class utile:
 if __name__ == "__main__":
     # TEST des methodes de la classe AMF
 
-    list_product = utile.getProductList()
+    list_product = util.getProductList()
     for product in list_product:
         print(product)
     
